@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2022
+# Copyright (C) 2015-2023
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,7 +18,7 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains the classes that represent Telegram InlineQueryResultVenue."""
 
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Optional
 
 from telegram._inline.inlinekeyboardmarkup import InlineKeyboardMarkup
 from telegram._inline.inlinequeryresult import InlineQueryResult
@@ -39,6 +39,9 @@ class InlineQueryResultVenue(InlineQueryResult):
       Foursquare details and Google Pace details are mutually exclusive. However, this
       behaviour is undocumented and might be changed by Telegram.
 
+    .. versionchanged:: 20.5
+        |removed_thumb_wildcard_note|
+
     Args:
         id (:obj:`str`): Unique identifier for this result,
             :tg-const:`telegram.InlineQueryResult.MIN_ID_LENGTH`-
@@ -59,9 +62,15 @@ class InlineQueryResultVenue(InlineQueryResult):
             to the message.
         input_message_content (:class:`telegram.InputMessageContent`, optional): Content of the
             message to be sent instead of the venue.
-        thumb_url (:obj:`str`, optional): Url of the thumbnail for the result.
-        thumb_width (:obj:`int`, optional): Thumbnail width.
-        thumb_height (:obj:`int`, optional): Thumbnail height.
+        thumbnail_url (:obj:`str`, optional): Url of the thumbnail for the result.
+
+            .. versionadded:: 20.2
+        thumbnail_width (:obj:`int`, optional): Thumbnail width.
+
+            .. versionadded:: 20.2
+        thumbnail_height (:obj:`int`, optional): Thumbnail height.
+
+            .. versionadded:: 20.2
 
     Attributes:
         type (:obj:`str`): :tg-const:`telegram.constants.InlineQueryResultType.VENUE`.
@@ -84,9 +93,15 @@ class InlineQueryResultVenue(InlineQueryResult):
             to the message.
         input_message_content (:class:`telegram.InputMessageContent`): Optional. Content of the
             message to be sent instead of the venue.
-        thumb_url (:obj:`str`): Optional. Url of the thumbnail for the result.
-        thumb_width (:obj:`int`): Optional. Thumbnail width.
-        thumb_height (:obj:`int`): Optional. Thumbnail height.
+        thumbnail_url (:obj:`str`): Optional. Url of the thumbnail for the result.
+
+            .. versionadded:: 20.2
+        thumbnail_width (:obj:`int`): Optional. Thumbnail width.
+
+            .. versionadded:: 20.2
+        thumbnail_height (:obj:`int`): Optional. Thumbnail height.
+
+            .. versionadded:: 20.2
 
     """
 
@@ -94,8 +109,8 @@ class InlineQueryResultVenue(InlineQueryResult):
         "longitude",
         "reply_markup",
         "google_place_type",
-        "thumb_width",
-        "thumb_height",
+        "thumbnail_width",
+        "thumbnail_height",
         "title",
         "address",
         "foursquare_id",
@@ -103,7 +118,7 @@ class InlineQueryResultVenue(InlineQueryResult):
         "google_place_id",
         "input_message_content",
         "latitude",
-        "thumb_url",
+        "thumbnail_url",
     )
 
     def __init__(
@@ -113,34 +128,33 @@ class InlineQueryResultVenue(InlineQueryResult):
         longitude: float,
         title: str,
         address: str,
-        foursquare_id: str = None,
-        foursquare_type: str = None,
-        reply_markup: InlineKeyboardMarkup = None,
-        input_message_content: "InputMessageContent" = None,
-        thumb_url: str = None,
-        thumb_width: int = None,
-        thumb_height: int = None,
-        google_place_id: str = None,
-        google_place_type: str = None,
+        foursquare_id: Optional[str] = None,
+        foursquare_type: Optional[str] = None,
+        reply_markup: Optional[InlineKeyboardMarkup] = None,
+        input_message_content: Optional["InputMessageContent"] = None,
+        google_place_id: Optional[str] = None,
+        google_place_type: Optional[str] = None,
+        thumbnail_url: Optional[str] = None,
+        thumbnail_width: Optional[int] = None,
+        thumbnail_height: Optional[int] = None,
         *,
-        api_kwargs: JSONDict = None,
+        api_kwargs: Optional[JSONDict] = None,
     ):
-
         # Required
         super().__init__(InlineQueryResultType.VENUE, id, api_kwargs=api_kwargs)
         with self._unfrozen():
-            self.latitude = latitude
-            self.longitude = longitude
-            self.title = title
-            self.address = address
+            self.latitude: float = latitude
+            self.longitude: float = longitude
+            self.title: str = title
+            self.address: str = address
 
             # Optional
-            self.foursquare_id = foursquare_id
-            self.foursquare_type = foursquare_type
-            self.google_place_id = google_place_id
-            self.google_place_type = google_place_type
-            self.reply_markup = reply_markup
-            self.input_message_content = input_message_content
-            self.thumb_url = thumb_url
-            self.thumb_width = thumb_width
-            self.thumb_height = thumb_height
+            self.foursquare_id: Optional[str] = foursquare_id
+            self.foursquare_type: Optional[str] = foursquare_type
+            self.google_place_id: Optional[str] = google_place_id
+            self.google_place_type: Optional[str] = google_place_type
+            self.reply_markup: Optional[InlineKeyboardMarkup] = reply_markup
+            self.input_message_content: Optional[InputMessageContent] = input_message_content
+            self.thumbnail_url: Optional[str] = thumbnail_url
+            self.thumbnail_width: Optional[int] = thumbnail_width
+            self.thumbnail_height: Optional[int] = thumbnail_height
