@@ -27,6 +27,7 @@ from telegram._utils.defaultvalue import DEFAULT_NONE as _DEFAULT_NONE
 from telegram._utils.defaultvalue import DefaultValue
 from telegram._utils.logging import get_logger
 from telegram._utils.types import JSONDict, ODVInput
+from telegram._utils.warnings import warn
 from telegram._version import __version__ as ptb_ver
 from telegram.error import (
     BadRequest,
@@ -39,6 +40,7 @@ from telegram.error import (
     TelegramError,
 )
 from telegram.request._requestdata import RequestData
+from telegram.warnings import PTBDeprecationWarning
 
 RT = TypeVar("RT", bound="BaseRequest")
 
@@ -70,6 +72,8 @@ class BaseRequest(
         finally:
             await request_object.shutdown()
 
+    .. seealso:: :meth:`__aenter__` and :meth:`__aexit__`.
+
     Tip:
         JSON encoding and decoding is done with the standard library's :mod:`json` by default.
         To use a custom library for this, you can override :meth:`parse_json_payload` and implement
@@ -99,6 +103,15 @@ class BaseRequest(
     """
 
     async def __aenter__(self: RT) -> RT:
+        """|async_context_manager| :meth:`initializes <initialize>` the Request.
+
+        Returns:
+            The initialized Request instance.
+
+        Raises:
+            :exc:`Exception`: If an exception is raised during initialization, :meth:`shutdown`
+                is called in this case.
+        """
         try:
             await self.initialize()
             return self
@@ -112,10 +125,29 @@ class BaseRequest(
         exc_val: Optional[BaseException],
         exc_tb: Optional[TracebackType],
     ) -> None:
+        """|async_context_manager| :meth:`shuts down <shutdown>` the Request."""
         # Make sure not to return `True` so that exceptions are not suppressed
         # https://docs.python.org/3/reference/datamodel.html?#object.__aexit__
         await self.shutdown()
 
+    @property
+    def read_timeout(self) -> Optional[float]:
+        """This property must return the default read timeout in seconds used by this class.
+        More precisely, the returned value should be the one used when
+        :paramref:`post.read_timeout` of :meth:post` is not passed/equal to :attr:`DEFAULT_NONE`.
+
+        .. versionadded:: 20.7
+
+        Warning:
+            For now this property does not need to be implemented by subclasses and will raise
+            :exc:`NotImplementedError` if accessed without being overridden. However, in future
+            versions, this property will be abstract and must be implemented by subclasses.
+
+        Returns:
+            :obj:`float` | :obj:`None`: The read timeout in seconds.
+        """
+        raise NotImplementedError
+
     @abc.abstractmethod
     async def initialize(self) -> None:
         """Initialize resources used by this class. Must be implemented by a subclass."""
@@ -271,8 +303,28 @@ class BaseRequest(
             TelegramError
 
         """
-        # TGs response also has the fields 'ok' and 'error_code'.
-        # However, we rather rely on the HTTP status code for now.
+        # Import needs to be here since HTTPXRequest is a subclass of BaseRequest
+        from telegram.request import HTTPXRequest  # pylint: disable=import-outside-toplevel
+
+        # 20 is the documented default value for all the media related bot methods and custom
+        # implementations of BaseRequest may explicitly rely on that. Hence, we follow the
+        # standard deprecation policy and deprecate starting with version 20.7.
+        # For our own implementation HTTPXRequest, we can handle that ourselves, so we skip the
+        # warning in that case.
+        has_files = request_data and request_data.multipart_data
+        if (
+            has_files
+            and not isinstance(self, HTTPXRequest)
+            and isinstance(write_timeout, DefaultValue)
+        ):
+            warn(
+                f"The `write_timeout` parameter passed to {self.__class__.__name__}.do_request "
+                "will default to `BaseRequest.DEFAULT_NONE` instead of 20 in future versions "
+                "for *all* methods of the `Bot` class, including methods sending media.",
+                PTBDeprecationWarning,
+                stacklevel=3,
+            )
+            write_timeout = 20
 
         try:
             code, payload = await self.do_request(
@@ -301,6 +353,8 @@ class BaseRequest(
         # In some special cases, we can raise more informative exceptions:
         # see https://core.telegram.org/bots/api#responseparameters and
         # https://core.telegram.org/bots/api#making-requests
+        # TGs response also has the fields 'ok' and 'error_code'.
+        # However, we rather rely on the HTTP status code for now.
         parameters = response_data.get("parameters")
         if parameters:
             migrate_to_chat_id = parameters.get("migrate_to_chat_id")
